@@ -1,7 +1,7 @@
 module Internal.Evidence (evByFiat) where
 
-import GHC.Tc.Types.Evidence (EvTerm(..))
-import GHC.Core.TyCo.Rep (UnivCoProvenance (..))
+import TcEvidence (EvTerm(..))
+import TyCoRep (UnivCoProvenance (..))
 
 import GhcApi.GhcPlugins
 
@@ -11,4 +11,4 @@ evByFiat :: String -- ^ Name the coercion should have
          -> Type   -- ^ The RHS of the equivalence relation (~)
          -> EvTerm
 evByFiat name t1 t2 =
-  EvExpr $ Coercion $ mkUnivCo (PluginProv name) Nominal t1 t2
\ No newline at end of file
+  EvCoercion $ mkUnivCo (PluginProv name) Nominal t1 t2
