@@ -1,8 +1,7 @@
 module Internal.Type (substType) where
 
 import Data.Maybe (fromMaybe)
-import GhcPlugins hiding (TcPlugin, mkSubst)
-import TcType (TcType)
+import TcType (TcTyVar, TcType)
 import TyCoRep (Type (..))
 
 -- | Apply substitutions in Types
@@ -22,8 +21,6 @@ substType _subst t@(ForAllTy _tv _ty) =
   -- TODO: Is it safe to do "dumb" substitution under binders?
   -- ForAllTy tv (substType subst ty)
   t
-substType subst (FunTy t1 t2) =
-  FunTy (substType subst t1) (substType subst t2)
 substType _ l@(LitTy _) = l
 substType subst (CastTy ty co) =
   CastTy (substType subst ty) co
