@@ -1,3 +1,3 @@
 module GhcApi.GhcPlugins (module GhcPlugins) where
 
-import GhcPlugins hiding (mkSubst)
+import GhcPlugins hiding (TcPlugin, mkSubst)
