@@ -2,6 +2,7 @@ module GhcApi.Constraint
   ( Ct(..)
   , CtEvidence(..)
   , CtLoc
+  , CanEqLHS(..)
   , ctLoc
   , ctEvId
   , mkNonCanonical
@@ -9,4 +10,4 @@ module GhcApi.Constraint
 where
 
 import GHC.Tc.Types.Constraint
-  (Ct (..), CtEvidence (..), CtLoc, ctLoc, ctEvId, mkNonCanonical)
+  (Ct (..), CtEvidence (..), CanEqLHS (..), CtLoc, ctLoc, ctEvId, mkNonCanonical)
